@@ -1,21 +1,24 @@
 /*
- * eth-none.c
+ * eth-win32.c
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: eth-win32.c,v 1.5 2002/12/14 05:33:05 dugsong Exp $
+ * $Id: eth-win32.c,v 1.11 2005/02/15 06:37:06 dugsong Exp $
  */
 
 #include "config.h"
 
+/* XXX - VC++ 6.0 bogosity */
+#define sockaddr_storage sockaddr
+#include <Packet32.h>
+#undef sockaddr_storage
+#include <Ntddndis.h>
+
 #include <errno.h>
 #include <stdlib.h>
 
 #include "dnet.h"
 
-#include <Packet32.h>
-#include <Ntddndis.h>
-
 struct eth_handle {
 	LPADAPTER	 lpa;
 	LPPACKET	 pkt;
@@ -107,7 +110,7 @@ eth_open(const char *device)
 	return (eth);
 }
 
-size_t
+ssize_t
 eth_send(eth_t *eth, const void *buf, size_t len)
 {
 	PacketInitPacket(eth->pkt, (void *)buf, len);
@@ -118,11 +121,13 @@ eth_send(eth_t *eth, const void *buf, size_t len)
 eth_t *
 eth_close(eth_t *eth)
 {
-	if (eth->pkt != NULL)
-		PacketFreePacket(eth->pkt);
-	if (eth->lpa != NULL)
-		PacketCloseAdapter(eth->lpa);
-	free(eth);
+	if (eth != NULL) {
+		if (eth->pkt != NULL)
+			PacketFreePacket(eth->pkt);
+		if (eth->lpa != NULL)
+			PacketCloseAdapter(eth->lpa);
+		free(eth);
+	}
 	return (NULL);
 }
 
